============
Installation
============

If you are using `Anaconda`_ or Miniconda, install Xpublish with the following commands::

    conda install -c conda-forge xpublish

If you are using virtualenv/pip, run the following command::

    python -m pip install xpublish

.. _Anaconda: https://www.anaconda.com/download/
